@@ -138,7 +138,7 @@ class WarehouseStorage(object):
             if bucket not in self.shelves:
                 self.shelves.append(bucket)
     
-    def retrieve(self, shelves=None):
+    def retrieve(self, shelves=None, auto_clean=False):
         """ Retrieve the content of the storage as a data flow
         @param shelves: List of shelves to retrieve all item, if shelves is None,
         the method retrieve all item from all shelves
@@ -152,6 +152,9 @@ class WarehouseStorage(object):
                 for item in get_input_item_flow(shelve_file):
                     yield item
                     
+            if auto_clean:
+                os.unlink(shelve)
+                    
     def __iter__(self):
         """ Just retrieve contents as an iterator """
         return self.retrieve()
